import { Schema as JSONSchema } from 'jsonschema';
/**
 * StAppsCore converter
 *
 * Converts TypeScript source files to JSON schema files
 */
export declare class SCConverter {
    private generator;
    /**
     * Create a new converter
     *
     * @param path Path to the project
     */
    constructor(path: string);
    /**
     * Get schema for specific StAppsCore type
     *
     * @param {string} type Type to get the schema for
     * @param {string} version Version to set for the schema
     * @returns {Schema} Generated schema
     */
    getSchema(type: string, version: string): JSONSchema;
}
/**
 * Convert TypeScript things to JSON schema files
 *
 * @param path Path to the project (where used *.ts files are, e.g. 'src/core')
 * @param inputDirs Directories (relative paths) to get source files from
 * @param outputDir Directory (relative path) to save output files to
 * @returns Promise that resolves with the amount of converted files
 */
export declare function convertFiles(path: string, inputDirs: string[], outputDir: string): Promise<number>;
